@@ -4,7 +4,7 @@
 #'
 #' @param id The character id of dataset. It accepts single id or multiple ids. Non-matched id(s) will be ignored.
 #' @param keep_title Whether to keep the dataset title in result. If the result is a table, the title is saved in "title" column. If the result is a list, the title is saved as list name.
-#' @param as Applicable if \code{x} has multiple rows. In \code{as = "table"} the fetched datasets will be saved in "dataset" column with list-column type where you can run \code{unnest()} afterwards. Otherwise the fetched datasets will be saved as list.
+#' @param as Applicable for multiple \code{id}. If \code{as = "table"}, the fetched datasets will be saved in "dataset" column with list-column type where you can run \code{tidyr::unnest()} afterwards. Otherwise the fetched datasets will be saved as list.
 #'
 #' @importFrom rlang arg_match .data
 #' @importFrom rappdirs user_cache_dir
@@ -30,13 +30,14 @@
 #'
 #' @export
 jabr_fetch <- function(id, keep_title = TRUE, as = "table") {
+  as <- arg_match(as, values = c("table", "list"))
+
   if (!is.character(id) || nchar(id) != 8L) {
     stop("`id` must be 8 digits character", call. = FALSE)
   }
 
-  as <- arg_match(as, values = c("table", "list"))
-
   jabr_cache_dir <- user_cache_dir("jabr")
+
   load(file = file.path(jabr_cache_dir, "jabr_data.rda"))
 
   id_ok <- keep(id, ~ is.element(.x, jabr_data$id))
@@ -60,6 +61,7 @@ jabr_fetch <- function(id, keep_title = TRUE, as = "table") {
     mutate(dataset = map(url, ckan_fetch)) %>%
     select(
       -.data$id,
+      -.data$group_id,
       -.data$provider,
       -.data$last_modified,
       -.data$url
