@@ -24,16 +24,13 @@
 jabr_list_dataset <- function(update = FALSE) {
   jabr_cache_dir <- user_cache_dir("jabr")
 
+  if (!dir.exists(jabr_cache_dir)) {
+    dir.create(jabr_cache_dir)
+  }
+
   if (!file.exists(file.path(jabr_cache_dir, "jabr_data.rda")) ||
     update) {
-    if (!dir.exists(jabr_cache_dir)) {
-      message("Preparing database, please wait a moment...")
-      dir.create(jabr_cache_dir)
-    }
-
-    if (update) {
-      message("Updating database, please wait a moment...")
-    }
+    message("Preparing database, please wait a moment...")
 
     jabr_data <-
       package_list_current(
@@ -41,12 +38,14 @@ jabr_list_dataset <- function(update = FALSE) {
         limit = 9999,
         url = "http://data.jabarprov.go.id"
       ) %>%
-      select(.data$resources, .data$author) %>%
+      select(group_id = .data$id, .data$resources, .data$author) %>%
       unnest(.data$resources) %>%
       filter(.data$format == "CSV") %>%
       transmute(
         id = str_extract(.data$id, "^[:alnum:]{8}"),
         id = as_id(.data$id),
+        group_id = str_extract(.data$group_id, "^[:alnum:]{8}"),
+        group_id = as_id(.data$group_id),
         title = str_replace_all(.data$name, "\\-", " ") %>%
           str_remove_all("\\.csv$") %>%
           toTitleCase(),
@@ -58,7 +57,12 @@ jabr_list_dataset <- function(update = FALSE) {
         url
       )
 
-    save(jabr_data, file = file.path(jabr_cache_dir, "jabr_data.rda"))
+    save(
+      jabr_data,
+      file = file.path(jabr_cache_dir, "jabr_data.rda"),
+      compress = "bzip2",
+      compression_level = 9
+    )
   }
 
   load(file = file.path(jabr_cache_dir, "jabr_data.rda"))
